# Changelog

## [0.0.1a2] - 2023-XX-XX

### Highlights

- Release of tstrait documentation in https://tskit.dev/tstrait/docs/latest/

### Fix

- Hide private functions and classes {pr}`73`
- Modify docstring explanations and examples {pr}`76`

### Documentation:

- Create infrastructure for documentation {pr}`77`
- Build initial documentation {pr}`78`
- Add Changelog to documentation {pr}`79`

### Contributors:

- Daiki Tagami
- Gertjan Bisschop
- Jerome Kelleher

## [0.0.1a1] - 2023-08-22

Initial alpha release of the package.

### Contributors:

- Daiki Tagami
- Gertjan Bisschop
- Jerome Kelleher